@@ -10,9 +10,11 @@ pub fn build(dir: Option<PathBuf>, renderer: String) -> Result<()> {
 
     match renderer.as_str() {
         "markdown" => zk.execute_build_process(&MarkdownRenderer)?,
-        "mdzk" => zk.execute_build_process(&HtmlMdzk)?,
-        _ => zk.execute_build_process(&HtmlHandlebars)?,
+        "mdbook" => zk.execute_build_process(&HtmlHandlebars)?,
+        _ => zk.execute_build_process(&HtmlMdzk)?,
     }
 
+    success!("Successfully built mdzk!");
+
     Ok(())
 }
