@@ -1,7 +1,8 @@
 // This is simply a modified version of https://github.com/rust-lang/mdBook/blob/master/src/cmd/watch.rs
 use crate::{CONFIG_FILE, SUMMARY_FILE};
 
-use mdbook::MDBook;
+use ignore::gitignore::Gitignore;
+use mdbook::{errors::*, MDBook};
 use notify::Watcher;
 use std::ffi::OsStr;
 use std::path::{Path, PathBuf};
@@ -19,21 +20,15 @@ fn remove_ignored_files(book_root: &Path, paths: &[PathBuf]) -> Vec<PathBuf> {
         .filter(|x| x.file_name() != Some(OsStr::new(SUMMARY_FILE)))
         .collect();
 
-    match find_gitignore(book_root) {
-        Some(gitignore_path) => {
-            match gitignore::File::new(gitignore_path.as_path()) {
-                Ok(exclusion_checker) => filter_ignored_files(exclusion_checker, paths),
-                Err(_) => {
-                    // We're unable to read the .gitignore file, so we'll silently allow everything.
-                    // Please see discussion: https://github.com/rust-lang/mdBook/pull/1051
-                    paths.iter().map(|path| path.to_path_buf()).collect()
-                }
-            }
-        }
-        None => {
-            // There is no .gitignore file.
-            paths.iter().map(|path| path.to_path_buf()).collect()
-        }
+    if let Some(gitignore_path) = find_gitignore(book_root) {
+        let (ignore, _) = Gitignore::new(gitignore_path);
+        paths
+            .iter()
+            .filter(|path| !ignore.matched(path, path.is_dir()).is_ignore())
+            .map(|path| path.to_path_buf())
+            .collect()
+    } else {
+        paths.iter().map(|path| path.to_path_buf()).collect()
     }
 }
 
@@ -44,27 +39,10 @@ fn find_gitignore(book_root: &Path) -> Option<PathBuf> {
         .find(|p| p.exists())
 }
 
-fn filter_ignored_files(exclusion_checker: gitignore::File, paths: Vec<&PathBuf>) -> Vec<PathBuf> {
-    paths
-        .iter()
-        .filter(|path| match exclusion_checker.is_excluded(path) {
-            Ok(exclude) => !exclude,
-            Err(error) => {
-                error!(
-                    "Unable to determine if {:?} is excluded: {:?}. Including it.",
-                    &path, error
-                );
-                true
-            }
-        })
-        .map(|path| path.to_path_buf())
-        .collect()
-}
-
 /// Calls the closure when a book source file is changed, blocking indefinitely.
-pub fn trigger_on_change<F>(book: &MDBook, closure: F)
+pub fn trigger_on_change<F>(book: &MDBook, closure: F) -> Result<()>
 where
-    F: Fn(Vec<PathBuf>, &Path),
+    F: Fn(Vec<PathBuf>, &Path) -> Result<()>,
 {
     use notify::DebouncedEvent::*;
     use notify::RecursiveMode::*;
@@ -88,7 +66,7 @@ where
 
     let _ = watcher.watch(book.theme_dir(), Recursive);
 
-    // Add the book.toml file to the watcher if it exists
+    // Add the mdzk.toml file to the watcher
     let _ = watcher.watch(book.root.join(CONFIG_FILE), NonRecursive);
 
     info!("Listening for changes...");
@@ -102,7 +80,7 @@ where
 
         let paths = all_events
             .filter_map(|event| {
-                debug!("Received filesystem event: {:?}", event);
+                debug!("Received filesystem event: {:#?}", event);
 
                 match event {
                     Create(path) | Write(path) | Remove(path) | Rename(_, path) => Some(path),
@@ -114,7 +92,7 @@ where
         let paths = remove_ignored_files(&book.root, &paths[..]);
 
         if !paths.is_empty() {
-            closure(paths, &book.root);
+            closure(paths, &book.root)?;
         }
     }
 }
